summaryrefslogtreecommitdiffstats
path: root/certmanager/lib/ui/backendconfigwidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/lib/ui/backendconfigwidget.cpp')
-rw-r--r--certmanager/lib/ui/backendconfigwidget.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/certmanager/lib/ui/backendconfigwidget.cpp b/certmanager/lib/ui/backendconfigwidget.cpp
index 720525a1a..b1a135a9f 100644
--- a/certmanager/lib/ui/backendconfigwidget.cpp
+++ b/certmanager/lib/ui/backendconfigwidget.cpp
@@ -21,11 +21,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -76,8 +76,8 @@ namespace Kleo {
class Kleo::BackendListView : public KListView
{
public:
- BackendListView( BackendConfigWidget* parent, const char* name = 0 )
- : KListView( parent, name ) {}
+ BackendListView( BackendConfigWidget* tqparent, const char* name = 0 )
+ : KListView( tqparent, name ) {}
/// return backend for currently selected (/current) item. Used by Configure button.
const Kleo::CryptoBackend* currentBackend() const;
@@ -92,7 +92,7 @@ public:
};
// Toplevel listviewitem for a given backend (e.g. "GpgME", "Kgpg/gpg v2")
-class Kleo::BackendListViewItem : public QListViewItem
+class Kleo::BackendListViewItem : public TQListViewItem
{
public:
BackendListViewItem( KListView* lv, TQListViewItem *prev, const CryptoBackend *cryptoBackend )
@@ -110,7 +110,7 @@ private:
// Checklist item under a BackendListViewItem
// (e.g. "GpgME supports protocol OpenPGP")
-class Kleo::ProtocolCheckListItem : public QCheckListItem
+class Kleo::ProtocolCheckListItem : public TQCheckListItem
{
public:
ProtocolCheckListItem( BackendListViewItem* blvi,
@@ -162,7 +162,7 @@ const Kleo::CryptoBackend* Kleo::BackendListView::currentBackend() const {
if ( !curItem ) // can't happen
return 0;
if ( lvi_cast<Kleo::ProtocolCheckListItem>( curItem ) )
- curItem = curItem->parent();
+ curItem = curItem->tqparent();
if ( const Kleo::BackendListViewItem * blvi = lvi_cast<Kleo::BackendListViewItem>( curItem ) )
return blvi->cryptoBackend();
return 0;
@@ -175,9 +175,9 @@ const Kleo::CryptoBackend* Kleo::BackendListView::chosenBackend( const char * pr
it.current() ; ++it )
if ( ProtocolCheckListItem * p = lvi_cast<ProtocolCheckListItem>( it.current() ) )
if ( p->isOn() && qstricmp( p->protocolName(), protocolName ) == 0 ) {
// OK that's the one. Now go up to the parent backend
// (need to do that in the listview since Protocol doesn't know it)
- if ( const BackendListViewItem * parItem = lvi_cast<BackendListViewItem>( it.current()->parent() ) )
+ if ( const BackendListViewItem * parItem = lvi_cast<BackendListViewItem>( it.current()->tqparent() ) )
return parItem->cryptoBackend();
}
return 0;
@@ -196,8 +196,8 @@ void Kleo::BackendListView::deselectAll( const char * protocolName, TQCheckListI
////
-Kleo::BackendConfigWidget::BackendConfigWidget( CryptoBackendFactory * factory, TQWidget * parent, const char * name, WFlags f )
- : TQWidget( parent, name, f ), d( 0 )
+Kleo::BackendConfigWidget::BackendConfigWidget( CryptoBackendFactory * factory, TQWidget * tqparent, const char * name, WFlags f )
+ : TQWidget( tqparent, name, f ), d( 0 )
{
assert( factory );
d = new Private();
@@ -175,9 +175,9 @@ const Kleo::CryptoBackend* Kleo::BackendListView::chosenBackend( const char * pr
if ( ProtocolCheckListItem * p = lvi_cast<ProtocolCheckListItem>( it.current() ) )
if ( p->isOn() && qstricmp( p->protocolName(), protocolName ) == 0 ) {
- // OK that's the one. Now go up to the parent backend
+ // OK that's the one. Now go up to the tqparent backend
// (need to do that in the listview since Protocol doesn't know it)